'use strict';

var react = require('react');

const InitialAsyncState = {
    loading: true,
    result: undefined,
    error: undefined,
};
const defaultSetLoading = _asyncState => InitialAsyncState;
const defaultSetResult = (result, _asyncState) => ({
    loading: false,
    result: result,
    error: undefined,
});
const defaultSetError = (error, _asyncState) => ({
    loading: false,
    result: undefined,
    error: error,
});
const DefaultOptions = {
    setLoading: defaultSetLoading,
    setResult: defaultSetResult,
    setError: defaultSetError,
};
const normalizeOptions = (options) => ({
    ...DefaultOptions,
    ...options,
});
const useAsyncState = (options) => {
    const [value, setValue] = react.useState(InitialAsyncState);
    return {
        value,
        setLoading: () => setValue(options.setLoading(value)),
        setResult: result => setValue(options.setResult(result, value)),
        setError: error => setValue(options.setError(error, value)),
    };
};
const useIsMounted = () => {
    const ref = react.useRef(false);
    react.useEffect(() => {
        ref.current = true;
        return () => {
            ref.current = false;
        };
    }, []);
    return () => ref.current;
};
const useCurrentPromise = () => {
    const ref = react.useRef(null);
    return {
        set: promise => (ref.current = promise),
        is: promise => ref.current === promise,
    };
};
const useAsync = (asyncFunction, params, options) => {
    const normalizedOptions = normalizeOptions(options);
    const AsyncState = useAsyncState(normalizedOptions);
    const isMounted = useIsMounted();
    const CurrentPromise = useCurrentPromise();
    // We only want to handle the promise result/error
    // if it is the last operation and the comp is still mounted
    const shouldHandlePromise = (p) => isMounted() && CurrentPromise.is(p);
    const executeAsyncOperation = () => {
        const promise = asyncFunction(...params);
        CurrentPromise.set(promise);
        AsyncState.setLoading();
        promise.then(result => {
            if (shouldHandlePromise(promise)) {
                AsyncState.setResult(result);
            }
        }, error => {
            if (shouldHandlePromise(promise)) {
                AsyncState.setError(error);
            }
        });
    };
    react.useEffect(() => {
        executeAsyncOperation();
    }, params);
    return {
        ...AsyncState.value,
        execute: executeAsyncOperation,
    };
};

exports.useAsync = useAsync;
//# sourceMappingURL=react-async-hook.cjs.development.js.map
